pub struct InMemoryProjectReferenceCache {
pub save_path: String,
pub cache: HashSet<String>,
pub local_source_service: LocalSourceService,
pub local_repo_service: LocalRepoService,
pub clone_path: String,
}Fields
save_path: Stringcache: HashSet<String>local_source_service: LocalSourceServicelocal_repo_service: LocalRepoServiceclone_path: StringImplementations
Sourceimpl InMemoryProjectReferenceCache
impl InMemoryProjectReferenceCache
Sourcepub fn new(save_path: String) -> Self
pub fn new(save_path: String) -> Self
Create a new InMemoryProjectReferenceCache instance. The save_path is the path to the file where the cache will be saved.
Sourcepub fn load_or_create(path: &str) -> Result<Self, SkootError>
pub fn load_or_create(path: &str) -> Result<Self, SkootError>
Load the cache from the file at save_path or create a new cache if the file does not exist.
Errors
Returns an error if the cache can’t be loaded or created.
Sourcepub fn load(&mut self) -> Result<(), SkootError>
pub fn load(&mut self) -> Result<(), SkootError>